pub struct ResolverBuilder<P> { /* private fields */ }Expand description
A builder to construct a Resolver.
Created by Resolver::builder.
Implementations
Sourceimpl<P: ConnectionProvider> ResolverBuilder<P>
impl<P: ConnectionProvider> ResolverBuilder<P>
Sourcepub fn with_options(self, options: ResolverOpts) -> Self
pub fn with_options(self, options: ResolverOpts) -> Self
Sets the ResolverOpts to be used by the resolver.
NB: A ResolverBuilder<P> will use the system configuration e.g., resolv.conf, by
default. Usage of this method will overwrite any options set by the system configuration.
See system_conf for functions that can parse a ResolverOpts
from the system configuration, or use options_mut() to
acquire a muitable reference to the existing ResolverOpts.
Sourcepub fn options_mut(&mut self) -> &mut ResolverOpts
pub fn options_mut(&mut self) -> &mut ResolverOpts
Returns a mutable reference to the ResolverOpts.
Sourcepub fn with_opportunistic_encryption(
self,
opportunistic_encryption: OpportunisticEncryption,
) -> Self
pub fn with_opportunistic_encryption( self, opportunistic_encryption: OpportunisticEncryption, ) -> Self
Set the opportunistic encryption configuration to be used by the resolver.
Sourcepub fn with_encrypted_transport_state(
self,
encrypted_transport_state: NameServerTransportState,
) -> Self
pub fn with_encrypted_transport_state( self, encrypted_transport_state: NameServerTransportState, ) -> Self
Set pre-existing encrypted transport state for use with opportunistic encryption.